@@ -36,12 +36,12 @@ use warnings;
 use 5.006;
 
 use List::MoreUtils qw{ firstidx };
-use Params::Util 0.25 qw{ _INSTANCE };
+use PPIx::Regexp::Util qw{ __instance };
 use Scalar::Util qw{ refaddr weaken };
 
-use PPIx::Regexp::Constant qw{ $MINIMUM_PERL };
+use PPIx::Regexp::Constant qw{ MINIMUM_PERL };
 
-our $VERSION = '0.008';
+our $VERSION = '0.023';
 
 =head2 ancestor_of
 
@@ -53,7 +53,7 @@ own ancestor.
 
 sub ancestor_of {
     my ( $self, $elem ) = @_;
-    _INSTANCE( $elem, __PACKAGE__ ) or return;
+    __instance( $elem, __PACKAGE__ ) or return;
     my $addr = refaddr( $self );
     while ( $addr != refaddr( $elem ) ) {
 	$elem = $elem->_parent() or return;
@@ -116,7 +116,7 @@ own descendant.
 
 sub descendant_of {
     my ( $self, $node ) = @_;
-    _INSTANCE( $node, __PACKAGE__ ) or return;
+    __instance( $node, __PACKAGE__ ) or return;
     return $node->ancestor_of( $self );
 }
 
@@ -164,13 +164,23 @@ sub parent {
 =head2 perl_version_introduced
 
 This method returns the version of Perl in which the element was
-introduced. But in practice it will never return a number less than
-5.006, since that is the minimum version supported by this package.
+introduced. This will be at least 5.000. Before 5.006 I am relying on
+the F<perldelta>, F<perlre>, and F<perlop> documentation, since I have
+been unable to build earlier Perls. Since I have found no documentation
+before 5.003, I assume that anything found in 5.003 is also in 5.000.
+
+Since this all depends on my ability to read and understand masses of
+documentation, the results of this method should be viewed with caution,
+if not downright skepticism.
+
+There are also cases which are ambiguous in various ways. For those see
+L<PPIx::Regexp/RESTRICTIONS>, and especially
+L<PPIx::Regexp/Changes in Syntax>.
 
 =cut
 
 sub perl_version_introduced {
-    return $MINIMUM_PERL;
+    return MINIMUM_PERL;
 }
 
 =head2 perl_version_removed
@@ -178,6 +188,11 @@ sub perl_version_introduced {
 This method returns the version of Perl in which the element was
 removed. If the element is still valid the return is C<undef>.
 
+All the I<caveats> to
+L<perl_version_introduced()|/perl_version_introduced> apply here also,
+though perhaps less severely since although many features have been
+introduced since 5.0, few have been removed.
+
 =cut
 
 sub perl_version_removed {
@@ -300,7 +315,7 @@ under C<$top>,
 
 sub nav {
     my ( $self ) = @_;
-    _INSTANCE( $self, __PACKAGE__ ) or return;
+    __instance( $self, __PACKAGE__ ) or return;
 
     # We do not use $self->parent() here because PPIx::Regexp overrides
     # this to return the (possibly) PPI object that initiated us.
@@ -340,7 +355,7 @@ sub nav {
 	if ( @arg ) {
 	    my $parent = shift @arg;
 	    if ( defined $parent ) {
-		_INSTANCE( $parent, __PACKAGE__ ) or return;
+		__instance( $parent, __PACKAGE__ ) or return;
 		weaken(
 		    $parent{$addr} = $parent );
 	    } else {
@@ -382,7 +397,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2010, Thomas R. Wyant, III
+Copyright (C) 2009-2011 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
