@@ -34,9 +34,9 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Structure };
 
-use Params::Util 0.25 qw{ _INSTANCE };
+use PPIx::Regexp::Util qw{ __instance };
 
-our $VERSION = '0.008';
+our $VERSION = '0.023';
 
 sub _new {
     my ( $class, @args ) = @_;
@@ -44,7 +44,7 @@ sub _new {
     my %brkt;
     $brkt{finish} = pop @args;
     $brkt{start} = shift @args;
-    _INSTANCE( $args[0], 'PPIx::Regexp::Token::Operator' )
+    __instance( $args[0], 'PPIx::Regexp::Token::Operator' )
 	and $args[0]->content() eq '^'
 	and $brkt{type} = shift @args;
     return $class->SUPER::_new( \%brkt, @args );
@@ -85,7 +85,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2010, Thomas R. Wyant, III
+Copyright (C) 2009-2011 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
