@@ -37,11 +37,11 @@ use base qw{ PPIx::Regexp::Token::Reference };
 
 use PPIx::Regexp::Constant qw{ RE_CAPTURE_NAME };
 
-our $VERSION = '0.015';
+our $VERSION = '0.023';
 
 sub perl_version_introduced {
     my ( $self ) = @_;
-    ( my $content = $self->content() ) =~ m/ \A [(] \d+ [)] \z /smx
+    $self->content() =~ m/ \A [(] \d+ [)] \z /smx
 	and return '5.005';
     return '5.009005';
 }
@@ -100,7 +100,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2010, Thomas R. Wyant, III
+Copyright (C) 2009-2011 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
