@@ -36,7 +36,7 @@ use base qw{ PPIx::Regexp::Token };
 
 use PPIx::Regexp::Constant qw{ COOKIE_CLASS MINIMUM_PERL };
 
-our $VERSION = '0.021';
+our $VERSION = '0.023';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
@@ -49,6 +49,8 @@ sub perl_version_introduced {
 	and return ( $self->{perl_version_introduced} = '5.013003' );
     $content =~ m/ \A \\ N [{] U [+] /smx
 	and return ( $self->{perl_version_introduced} = '5.008' );
+    $content =~ m/ \A \\ x [{] /smx	# }
+	and return ( $self->{perl_version_introduced} = '5.006' );
     $content =~ m/ \A \\ N /smx
 	and return ( $self->{perl_version_introduced} = '5.006001' );
     return ( $self->{perl_version_introduced} = MINIMUM_PERL );
